@@ -8,13 +8,15 @@ use Class::Accessor::Lite (
 );
 use DateTime;
 use Getopt::Long qw(:config posix_default no_ignore_case no_ignore_case_always);
+use Log::Minimal env_debug => 'KOYOMI_LOG_DEBUG';
+use Proc::Wait3;
 use Smart::Args;
 use Time::Piece;
 
 use App::Koyomi::Context;
 use App::Koyomi::Schedule;
 
-use version; our $VERSION = 'v0.5.2';
+use version; our $VERSION = 'v0.6.0';
 
 sub new {
     args(
@@ -83,6 +85,9 @@ sub run {
             $seconds = $self->config->{debug}{worker}{sleep_seconds} // $seconds;
         }
         sleep($seconds);
+        while (my @child_proc_info = wait3(0)) {
+            debugf('Exit %d', $child_proc_info[0]);
+        }
     }
 }
 
